@@ -29,7 +29,7 @@
 # ==============================================================================
 
 from .protocol import *
-from .attributes import *
+
 from .node import *
 from .server import *
 from .client import *
@@ -43,40 +43,19 @@ __all__ = [
     #
     #  Protocol
     #
-    'MessageType', 'MessageLength', 'TransactionID',
-    'Header', 'Package',
-    # message types
-    'BindRequest', 'BindResponse', 'BindErrorResponse',
-    'SharedSecretRequest', 'SharedSecretResponse', 'SharedSecretErrorResponse',
+    'MessageType', 'TransactionID', 'Header', 'Package',
 
-    #
-    #  Attributes
-    #
-    'Attribute', 'AttributeType', 'AttributeLength', 'AttributeValue',
-    # attribute types
-    'MappedAddress', 'ResponseAddress',
-    'ChangeRequest',
-    'SourceAddress', 'ChangedAddress',
-    'Username', 'Password', 'MessageIntegrity',
-    'ErrorCode', 'UnknownAttributes',
-    'ReflectedFrom', 'Realm', 'Nonce',
-    'XorMappedAddress', 'XorMappedAddress2', 'XorOnly',
-    'Software', 'AlternateServer', 'Fingerprint',
-    # attribute values
-    'MappedAddressValue', 'ResponseAddressValue',
-    'ChangeRequestValue', 'ChangeIP', 'ChangePort', 'ChangeIPAndPort',
-    'SourceAddressValue', 'ChangedAddressValue',
-    # 'UsernameValue', 'PasswordValue', 'MessageIntegrityValue',
-    # 'ErrorCodeValue', 'UnknownAttributesValue',
-    # 'ReflectedFromValue', 'RealmValue', 'NonceValue',
-    'XorMappedAddressValue', 'XorMappedAddressValue2',  # 'XorOnlyValue',
-    'SoftwareValue',  # 'AlternateServerValue', 'FingerprintValue',
+    'AttributeType', 'AttributeLength', 'AttributeValue',
+    'Attribute', 'AttributeParser',
+
+    'MappedAddressValue',
+    'XorMappedAddressValue', 'XorMappedAddressValue2',
+    'SourceAddressValue', 'ResponseAddressValue', 'ChangedAddressValue',
+    'ChangeRequestValue', 'SoftwareValue',
 
     #
     #  Service
     #
     'NatType',
     'Client', 'Server',
-
-    'get_local_ip',
 ]
